import { ChangeDetectionStrategy, Component, ContentChildren, Host, Inject, Input, NgModule, ViewChild, ViewContainerRef, ViewEncapsulation, forwardRef } from '@angular/core';

var LazyBlockComponent = /** @class */ (function () {
    /**
     * @param {?} page
     */
    function LazyBlockComponent(page) {
        this.isRender = false;
        this.page = page;
    }
    /**
     * @return {?}
     */
    LazyBlockComponent.prototype.render = function () {
        var _this = this;
        this.tplVcRef.createEmbeddedView(this.tplRef);
        this.isRender = true;
        requestAnimationFrame(function () {
            _this.page.render();
        });
    };
    LazyBlockComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lazy-block',
                    styles: ['lazy-block {display:block}'],
                    template: '<ng-template #tpl><ng-content></ng-content></ng-template>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyBlockComponent.ctorParameters = function () { return [
        { type: LazyPageComponent, decorators: [{ type: Host }, { type: Inject, args: [forwardRef(function () { return LazyPageComponent; }),] },] },
    ]; };
    LazyBlockComponent.propDecorators = {
        'tplRef': [{ type: ViewChild, args: ['tpl',] },],
        'tplVcRef': [{ type: ViewChild, args: ['tpl', { read: ViewContainerRef },] },],
    };
    return LazyBlockComponent;
}());

var LazyPageComponent = /** @class */ (function () {
    function LazyPageComponent() {
        this.index = 0;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    LazyPageComponent.prototype.ngOnChanges = function (changes) {
        if (changes.index && changes.index.currentValue) {
            this.index = +changes.index.currentValue;
        }
    };
    /**
     * @return {?}
     */
    LazyPageComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        var /** @type {?} */ initBlock = this.blocks.find(function (item, index) { return index === _this.index; });
        if (initBlock) {
            initBlock.render();
        }
        else {
            this.blocks[0].render();
            this.index = 0;
        }
    };
    /**
     * @return {?}
     */
    LazyPageComponent.prototype.render = function () {
        var /** @type {?} */ block = this.blocks.find(function (item) { return !item.isRender; });
        if (block) {
            block.render();
        }
    };
    LazyPageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lazy-page',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyPageComponent.ctorParameters = function () { return []; };
    LazyPageComponent.propDecorators = {
        'index': [{ type: Input },],
        'blocks': [{ type: ContentChildren, args: [LazyBlockComponent, { descendants: true },] },],
    };
    return LazyPageComponent;
}());

var LazyRenderModule = /** @class */ (function () {
    function LazyRenderModule() {
    }
    LazyRenderModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [LazyPageComponent, LazyBlockComponent],
                    exports: [LazyPageComponent, LazyBlockComponent]
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyRenderModule.ctorParameters = function () { return []; };
    return LazyRenderModule;
}());

export { LazyRenderModule, LazyPageComponent, LazyBlockComponent };
