(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core'], factory) :
	(factory((global['angular-lazy-render'] = {}),global.ng.core));
}(this, (function (exports,core) { 'use strict';

var LazyBlockComponent = /** @class */ (function () {
    /**
     * @param {?} page
     */
    function LazyBlockComponent(page) {
        this.isRender = false;
        this.page = page;
    }
    /**
     * @return {?}
     */
    LazyBlockComponent.prototype.render = function () {
        var _this = this;
        this.tplVcRef.createEmbeddedView(this.tplRef);
        this.isRender = true;
        requestAnimationFrame(function () {
            _this.page.render();
        });
    };
    LazyBlockComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'lazy-block',
                    styles: ['lazy-block {display:block}'],
                    template: '<ng-template #tpl><ng-content></ng-content></ng-template>',
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    encapsulation: core.ViewEncapsulation.None
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyBlockComponent.ctorParameters = function () { return [
        { type: LazyPageComponent, decorators: [{ type: core.Host }, { type: core.Inject, args: [core.forwardRef(function () { return LazyPageComponent; }),] },] },
    ]; };
    LazyBlockComponent.propDecorators = {
        'tplRef': [{ type: core.ViewChild, args: ['tpl',] },],
        'tplVcRef': [{ type: core.ViewChild, args: ['tpl', { read: core.ViewContainerRef },] },],
    };
    return LazyBlockComponent;
}());

var LazyPageComponent = /** @class */ (function () {
    function LazyPageComponent() {
        this.index = 0;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    LazyPageComponent.prototype.ngOnChanges = function (changes) {
        if (changes.index && changes.index.currentValue) {
            this.index = +changes.index.currentValue;
        }
    };
    /**
     * @return {?}
     */
    LazyPageComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        var /** @type {?} */ initBlock = this.blocks.find(function (item, index) { return index === _this.index; });
        if (initBlock) {
            initBlock.render();
        }
        else {
            this.blocks[0].render();
            this.index = 0;
        }
    };
    /**
     * @return {?}
     */
    LazyPageComponent.prototype.render = function () {
        var /** @type {?} */ block = this.blocks.find(function (item) { return !item.isRender; });
        if (block) {
            block.render();
        }
    };
    LazyPageComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'lazy-page',
                    template: '<ng-content></ng-content>',
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyPageComponent.ctorParameters = function () { return []; };
    LazyPageComponent.propDecorators = {
        'index': [{ type: core.Input },],
        'blocks': [{ type: core.ContentChildren, args: [LazyBlockComponent, { descendants: true },] },],
    };
    return LazyPageComponent;
}());

var LazyRenderModule = /** @class */ (function () {
    function LazyRenderModule() {
    }
    LazyRenderModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [LazyPageComponent, LazyBlockComponent],
                    exports: [LazyPageComponent, LazyBlockComponent]
                },] },
    ];
    /**
     * @nocollapse
     */
    LazyRenderModule.ctorParameters = function () { return []; };
    return LazyRenderModule;
}());

exports.LazyRenderModule = LazyRenderModule;
exports.LazyPageComponent = LazyPageComponent;
exports.LazyBlockComponent = LazyBlockComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
